@@ -1,5 +1,6 @@
 import builtins
 import inspect
+import math
 from types import FunctionType, CodeType, LambdaType
 
 
@@ -278,6 +279,9 @@ def des_func(obj):
         if len(args["co_names"]) != 0 and key in des(args["co_names"]):  # list
             if key != des(args["co_name"]):
                 globs[key] = des(obj["__globals__"][key])
+                if key == "math":
+                    globs[key] = math
+
 
     for k, v in args.items():
         if k == "co_consts":
